==> yy-formulas-1.0.0.tgz: package/es/components/TabsComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import Tabs, { TabPane } from 'rc-tabs';
import TabContent from "rc-tabs/es/TabContent";
import ScrollableInkTabBar from "rc-tabs/es/ScrollableInkTabBar";
import DocumentComponents from './DocumentComponents';
import FixedComponents from './FixedComponents';
import SubjectComponents from './SubjectComponents';

var TabsComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(TabsComponents, _React$Component);

  function TabsComponents(props) {
    var _this;

    _classCallCheck(this, TabsComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(TabsComponents).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.state = {
      activeKey: _this.props.activeKey
    };
    return _this;
  } // componentWillReceiveProps(nextProps){
  //   if(nextProps.activeKey!=this.state.activeKey){
  //     let activeKey = nextProps.activeKey
  //     this.setState({activeKey})
  //   }
  // }


  _createClass(TabsComponents, [{
    key: "onChange",
    value: function onChange(activeKey) {
      this.setState({
        activeKey: activeKey
      });
      this.props.onDesc();
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          prefixCls = _this$props.prefixCls,
          tabs = _this$props.tabs,
          DocumentTreeData = _this$props.DocumentTreeData,
          ReferDataUrl = _this$props.ReferDataUrl,
          fixedData = _this$props.fixedData,
          SubjectData = _this$props.SubjectData,
          onDesc = _this$props.onDesc;
      console.log(this.props);
      return React.createElement(Tabs, {
        prefixCls: prefixCls,
        defaultActiveKey: this.state.activeKey,
        activeKey: this.state.activeKey,
        onChange: this.onChange,
        renderTabBar: function renderTabBar() {
          return React.createElement(ScrollableInkTabBar, null);
        },
        renderTabContent: function renderTabContent() {
          return React.createElement(TabContent, null);
        }
      }, tabs.map(function (item) {
        var Component = item.component;
        var props = {
          onInsertValue: _this2.props.onInsertValue,
          ReferDataUrl: ReferDataUrl,
          fixedData: fixedData,
          onDesc: onDesc
        };

        if (typeof item.component === 'string') {
          if (item.component === 'Document') {
            Component = DocumentComponents;
            props['DocumentTreeData'] = DocumentTreeData;
          } else if (item.component === 'Fixed') {
            Component = FixedComponents;
          } else if (item.component === 'Subject') {
            props['DocumentTreeData'] = DocumentTreeData;
            props['SubjectData'] = SubjectData;
            Component = SubjectComponents;
          }
        }

        return React.createElement(TabPane, {
          key: item.id,
          tab: item.name,
          disabled: item.disabled
        }, React.createElement(Component, _extends({}, props, {
          item: item
        })));
      }));
    }
  }]);

  return TabsComponents;
}(React.Component);

TabsComponents.propTypes = {
  prefixCls: PropTypes.string,
  tabs: PropTypes.array,
  activeKey: PropTypes.string,
  ReferDataUrl: PropTypes.string
};
TabsComponents.defaultProps = {
  prefixCls: 'rc-tabs',
  tabs: [],
  activeKey: '0',
  ReferDataUrl: ''
};
polyfill(TabsComponents);
export default TabsComponents;

==> yy-formulas-1.0.1.tgz: package/es/components/TabsComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import Tabs, { TabPane } from 'rc-tabs';
import TabContent from "rc-tabs/es/TabContent";
import ScrollableInkTabBar from "rc-tabs/es/ScrollableInkTabBar";
import DocumentComponents from './DocumentComponents';
import FixedComponents from './FixedComponents';
import SubjectComponents from './SubjectComponents';

var TabsComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(TabsComponents, _React$Component);

  function TabsComponents(props) {
    var _this;

    _classCallCheck(this, TabsComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(TabsComponents).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.state = {
      activeKey: _this.props.activeKey
    };
    return _this;
  } // componentWillReceiveProps(nextProps){
  //   if(nextProps.activeKey!=this.state.activeKey){
  //     let activeKey = nextProps.activeKey
  //     this.setState({activeKey})
  //   }
  // }


  _createClass(TabsComponents, [{
    key: "onChange",
    value: function onChange(activeKey) {
      this.setState({
        activeKey: activeKey
      });
      this.props.onDesc();
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          prefixCls = _this$props.prefixCls,
          tabs = _this$props.tabs,
          DocumentTreeData = _this$props.DocumentTreeData,
          ReferDataUrl = _this$props.ReferDataUrl,
          fixedData = _this$props.fixedData,
          SubjectData = _this$props.SubjectData,
          onDesc = _this$props.onDesc; // console.log(this.props)

      return React.createElement(Tabs, {
        prefixCls: prefixCls,
        defaultActiveKey: this.state.activeKey,
        activeKey: this.state.activeKey,
        onChange: this.onChange,
        renderTabBar: function renderTabBar() {
          return React.createElement(ScrollableInkTabBar, null);
        },
        renderTabContent: function renderTabContent() {
          return React.createElement(TabContent, null);
        }
      }, tabs.map(function (item) {
        var Component = item.component;
        var props = {
          onInsertValue: _this2.props.onInsertValue,
          ReferDataUrl: ReferDataUrl,
          fixedData: fixedData,
          onDesc: onDesc
        };

        if (typeof item.component === 'string') {
          if (item.component === 'Document') {
            Component = DocumentComponents;
            props['DocumentTreeData'] = DocumentTreeData;
          } else if (item.component === 'Fixed') {
            Component = FixedComponents;
          } else if (item.component === 'Subject') {
            props['DocumentTreeData'] = DocumentTreeData;
            props['SubjectData'] = SubjectData;
            Component = SubjectComponents;
          }
        }

        return React.createElement(TabPane, {
          key: item.id,
          tab: item.name,
          disabled: item.disabled
        }, React.createElement(Component, _extends({}, props, {
          item: item
        })));
      }));
    }
  }]);

  return TabsComponents;
}(React.Component);

TabsComponents.propTypes = {
  prefixCls: PropTypes.string,
  tabs: PropTypes.array,
  activeKey: PropTypes.string,
  ReferDataUrl: PropTypes.string
};
TabsComponents.defaultProps = {
  prefixCls: 'rc-tabs',
  tabs: [],
  activeKey: '0',
  ReferDataUrl: ''
};
polyfill(TabsComponents);
export default TabsComponents;
